==> vradi-swing-0.0.5-sources.jar: com/jurismarches/vradi/ui/admin/nav/AdminGroupNavUI.java <==
package com.jurismarches.vradi.ui.admin.nav;

import com.jurismarches.vradi.VradiContext;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.ui.admin.AdminHandler;
import com.jurismarches.vradi.ui.admin.nav.*;
import com.jurismarches.vradi.ui.helpers.AdminNavigationTreeHelper;
import com.jurismarches.vradi.ui.helpers.UIHelper;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.*;
import jaxx.runtime.JAXXBinding;
import jaxx.runtime.JAXXContext;
import jaxx.runtime.JAXXObjectDescriptor;
import jaxx.runtime.swing.*;
import jaxx.runtime.swing.EntityComboBox;
import jaxx.runtime.swing.editor.*;
import static jaxx.runtime.SwingUtil.createImageIcon;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static org.nuiton.i18n.I18n._;
import static org.nuiton.i18n.I18n.n_;

public class AdminGroupNavUI extends com.jurismarches.vradi.ui.admin.AdminNavUI {

    /*-----------------------------------------------------------------------*/
    /*------------------------- Other static fields -------------------------*/
    /*-----------------------------------------------------------------------*/

    private static final String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1TsW4TQRAdH7GDE1AgBisII4XESrkGUQZBgiFgywSEhRThJmvfyt7obm/ZnXMOCsQn8AnQ0yDRUSEKagoaxC8gREGL2N1zfAk2git2TzPzZt7Mvnn9DfJawcU9miRExQJ5yEhzc2fnXneP9fAm0z3FJUYK0i/ngdeBeX9s1wirnZaF10bwWj0KZSSYOIReb8GcxicB0wPGEOHCUURP61p77F5PZKwOso5JTcv68sd374X//JUHkEjDzray/C9U1slMCzzuIyyaSkNaC6joGxqKi77he9La6gHVepuG7DE8g9kWFCRVJhnCyv+37HI4fCIRFvoqiuWmH3KxTYcPGwhXelFI9mLFdUhVb8A0GSrqcxJzQm0YEXRIHOC2hTqUlC5jAaFUbbuCDcGR04A/ZeoSwpobgkksecAUSTmRichDabhpQOGtxJ71SKDrctHOICF634yENO9TwYIMUqw2b8SIkTD1SkcCU7MNW5iMvmwNZ0ZOBeePPJcRAsmEkL1UrgN5FRszwlJnUjsPjCtVzdIfqrEJnfdXufT53de3WwdS8Uzts1NDDyndPKFUkWQKuS29kOokRh7U7lK53oGiZoFZE7cGlSnE2iO3IWfqnbZwYuHkDtUDkyI/++X9h/Lup2PgbcFcEFF/i9r4BhRxoMwUosBP5PUNx+jE/nFznrLcEGaQJfaFrnIRcMGWKRrhdmNk1xIzhsqUMYy5dIsff5babzYORpEz1M79NTwbR/4RFNJqbm9GKzF1T+alZrEfZdKftgw5e5fkSFEVdy5P9mrNK/ZYTWJ7VR1l+7fmfGWT4TeU2beLxwQAAA==";
    private static final long serialVersionUID = 1L;

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Internal states ---------------------------*/
    /*-----------------------------------------------------------------------*/

    private boolean allComponentsCreated;

    /*-----------------------------------------------------------------------*/
    /*------------------------ Protected components  ------------------------*/
    /*-----------------------------------------------------------------------*/

    protected AdminGroupNavUI groupAdminNavUI = this;

    /*-----------------------------------------------------------------------*/
    /*------------------------- Private components  -------------------------*/
    /*-----------------------------------------------------------------------*/

    private javax.swing.JButton $JButton0;
    private javax.swing.JButton $JButton1;

    /*-----------------------------------------------------------------------*/
    /*---------------------- Raw body code from script ----------------------*/
    /*-----------------------------------------------------------------------*/

    // FIXME EC-20100415 hack for hack already present in parent !!!
        protected boolean contextInitialized;
    
    
        public  AdminGroupNavUI(JAXXContext parentContext, AdminNavigationTreeHelper helper) {
            super(parentContext, helper);$initialize();
    
            // FIXME EC-20100415 hack for hack already present in parent !!!
            contextInitialized = true;
        $initialize();
    }
    
        public AdminHandler getHandler() {
            return getContextValue(AdminHandler.class);
        }

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Statics methods ---------------------------*/
    /*-----------------------------------------------------------------------*/

    public static JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return JAXXUtil.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Constructors  ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public AdminGroupNavUI() {
        super();
        $initialize();
    }

    public AdminGroupNavUI(JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Event methods ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public void doActionPerformed__on__$JButton0(java.awt.event.ActionEvent event) {
        getHandler().importClientUsersDBCSV(this);
    }

    public void doActionPerformed__on__$JButton1(java.awt.event.ActionEvent event) {
        getHandler().exportClientUsersDBCSV(this);
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Protected acessors methods  ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected javax.swing.JButton get$JButton0() {
        return $JButton0;
    }

    protected javax.swing.JButton get$JButton1() {
        return $JButton1;
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Components creation methods ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected void addChildrenToImportExportContent() {
        if (!allComponentsCreated) {
            return;
        }
        importExportContent.add($JButton0);
        importExportContent.add($JButton1);
    }

    @Override
    protected void createImportExportContent() {
        super.createImportExportContent();
        importExportContent.setName("importExportContent");
    }

    /*-----------------------------------------------------------------------*/
    /*------------------------ Internal jaxx methods ------------------------*/
    /*-----------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToImportExportContent();
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("groupAdminNavUI", this);
        contextInitialized = false;
        // inline creation of $JButton0
        $objectMap.put("$JButton0", $JButton0 = new javax.swing.JButton());
        $JButton0.setName("$JButton0");
        $JButton0.setText(_("vradi.adminClient.importGroupCSV"));
        $JButton0.addActionListener(JAXXUtil.getEventListener(ActionListener.class, "actionPerformed", this, "doActionPerformed__on__$JButton0"));
        // inline creation of $JButton1
        $objectMap.put("$JButton1", $JButton1 = new javax.swing.JButton());
        $JButton1.setName("$JButton1");
        $JButton1.setText(_("vradi.adminClient.exportGroupCSV"));
        $JButton1.addActionListener(JAXXUtil.getEventListener(ActionListener.class, "actionPerformed", this, "doActionPerformed__on__$JButton1"));
        // inline creation of groupAdminNavUI
        setName("groupAdminNavUI");
        
        $completeSetup();
    }

}

==> vradi-swing-0.1.0-sources.jar: com/jurismarches/vradi/ui/admin/nav/AdminGroupNavUI.java <==
package com.jurismarches.vradi.ui.admin.nav;

import com.jurismarches.vradi.VradiContext;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.ui.admin.AdminHandler;
import com.jurismarches.vradi.ui.admin.helpers.AdminNavigationTreeHelper;
import com.jurismarches.vradi.ui.admin.nav.*;
import com.jurismarches.vradi.ui.helpers.UIHelper;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.*;
import jaxx.runtime.JAXXBinding;
import jaxx.runtime.JAXXContext;
import jaxx.runtime.JAXXObjectDescriptor;
import jaxx.runtime.swing.*;
import jaxx.runtime.swing.EntityComboBox;
import jaxx.runtime.swing.editor.*;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import static jaxx.runtime.SwingUtil.createImageIcon;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static org.nuiton.i18n.I18n._;
import static org.nuiton.i18n.I18n.n_;

public class AdminGroupNavUI extends com.jurismarches.vradi.ui.admin.AdminNavUI {

    /*-----------------------------------------------------------------------*/
    /*------------------------- Other static fields -------------------------*/
    /*-----------------------------------------------------------------------*/

    private static final String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1SPW8TQRAdH7aDk6B8WESJSIRDqNcgSiNIMARimYCwkCLcsPat7LXu9pbdPedoED+BnwA9DRIdFaKgpqBB/AWEKGgRs+uPi7ERXDF7mpk382bmvf4GOa1gu0eThKhYGB4yUts7OrrX6rG2ucl0W3FpIgWDL+OB14QFf+zXBnaadQsvD+HlahTKSDBxAl2pw7w2TwOmu4wZA1uTiLbW5cY4XElkrEZVx6RmVX3547v3wn/+ygNIJLLL4iilf6HSSbJ18LhvYBU79Wk5oKKDNBQXHeR7xvqqAdX6kIbsCTyDuTrkJVVYzMCF/x/Z1XD4RBpY6qgolnt+yMUh7T88MHClHYWkFyuuQ6raXaZJX1Gfk5gTatOIoH3iALct1KGkdBXzBoocOytzK7G2Ggnj6K1a8gnRxzgLqd2nggUppHCxdiM2JhKXED6ROHDbtMXp7MvWsTIMKjg3sWe8IEkvmK4404ScitFtYL05ffQHGBqce/2Pc9uCLvprrfj53de3+6Mbe9j77MzUExLF3UsVSaYMt62XBgeODQ/Kd6msNKGgWYD6dvrdnEGsMQwjOey3YuHEwskdqrtYIjf35f2HtcefToG3D/NBRP19avMPoGC6CrcQBX4ir+86RovHp9EuW24GsoYl9kJXuQi4YCVqUHGt2LBrCa5hc8YaxlxahY8/i403u6NVZJDaxl/T03XkHkF+0M0JfqjlmQJfkJrFfpRqdpaKM/ZdlkNFbTi7NT2rdZ+3ppTE9tl2lO3fjosVscJvFTXzBYAEAAA=";
    private static final Log log = LogFactory.getLog(com.jurismarches.vradi.ui.admin.nav.AdminGroupNavUI.class);
    private static final long serialVersionUID = 1L;

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Internal states ---------------------------*/
    /*-----------------------------------------------------------------------*/

    private boolean allComponentsCreated;
    private boolean contextInitialized = true;

    /*-----------------------------------------------------------------------*/
    /*------------------------ Protected components  ------------------------*/
    /*-----------------------------------------------------------------------*/

    protected AdminGroupNavUI groupAdminNavUI = this;

    /*-----------------------------------------------------------------------*/
    /*------------------------- Private components  -------------------------*/
    /*-----------------------------------------------------------------------*/

    private javax.swing.JButton $JButton0;
    private javax.swing.JButton $JButton1;

    /*-----------------------------------------------------------------------*/
    /*---------------------- Raw body code from script ----------------------*/
    /*-----------------------------------------------------------------------*/

    // FIXME EC-20100415 hack for hack already present in parent !!! Useless now, keep it if commenting it created some bug
        //protected boolean contextInitialized = false;
    
        public  AdminGroupNavUI(JAXXContext parentContext, AdminNavigationTreeHelper helper) {
            super(parentContext, helper);$initialize();
    
            // FIXME EC-20100415 hack for hack already present in parent !!! Useless now, keep it if commenting it created some bug
            //contextInitialized = true;
        $initialize();
    }
    
        public AdminHandler getHandler() {
            return getContextValue(AdminHandler.class);
        }

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Statics methods ---------------------------*/
    /*-----------------------------------------------------------------------*/

    public static JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return JAXXUtil.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Constructors  ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public AdminGroupNavUI() {
        super();
        $initialize();
    }

    public AdminGroupNavUI(JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Event methods ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public void doActionPerformed__on__$JButton0(java.awt.event.ActionEvent event) {
        getHandler().importClientUsersDBCSV(this);
    }

    public void doActionPerformed__on__$JButton1(java.awt.event.ActionEvent event) {
        getHandler().exportClientUsersDBCSV(this);
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Protected acessors methods  ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected javax.swing.JButton get$JButton0() {
        return $JButton0;
    }

    protected javax.swing.JButton get$JButton1() {
        return $JButton1;
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Components creation methods ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected void addChildrenToImportExportContent() {
        if (!allComponentsCreated) {
            return;
        }
        importExportContent.add($JButton0);
        importExportContent.add($JButton1);
    }

    @Override
    protected void createImportExportContent() {
        super.createImportExportContent();
        importExportContent.setName("importExportContent");
    }

    /*-----------------------------------------------------------------------*/
    /*------------------------ Internal jaxx methods ------------------------*/
    /*-----------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToImportExportContent();
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("groupAdminNavUI", this);
        // inline creation of $JButton0
        $objectMap.put("$JButton0", $JButton0 = new javax.swing.JButton());
        
        $JButton0.setName("$JButton0");
        $JButton0.setText(_("vradi.adminClient.importGroupCSV"));
        $JButton0.addActionListener(JAXXUtil.getEventListener(ActionListener.class, "actionPerformed", this, "doActionPerformed__on__$JButton0"));
        // inline creation of $JButton1
        $objectMap.put("$JButton1", $JButton1 = new javax.swing.JButton());
        
        $JButton1.setName("$JButton1");
        $JButton1.setText(_("vradi.adminClient.exportGroupCSV"));
        $JButton1.addActionListener(JAXXUtil.getEventListener(ActionListener.class, "actionPerformed", this, "doActionPerformed__on__$JButton1"));
        // inline creation of groupAdminNavUI
        setName("groupAdminNavUI");
        
        $completeSetup();
    }

}
